## ----setup, include=FALSE-----------------------------------------
source("config/setup.R")

## ---- results = "hide", message = FALSE, error = FALSE, warning = FALSE----
#-----------------------------------------------------------------------
# Load packages.

library(lattice)
library(latticeExtra)
library(doBy)
library(multcomp)
library(plyr)
library(wzRfun)
library(nematistics)

## -----------------------------------------------------------------
#-----------------------------------------------------------------------

# A shorter name is better, avoid mispellings.
cp <- coffee_pathogenicity
str(cp)

xyplot(atw ~ ind^0.3 | rootstock,
       data = cp,
       type = c("p", "a"),
       grid = TRUE,
       xlab = "Initial nematode density (transformed)",
       ylab = "Aerial top weight (g)")

xyplot(frw ~ ind^0.3 | rootstock,
       data = cp,
       type = c("p", "a"),
       grid = TRUE,
       xlab = "Initial nematode density (transformed)",
       ylab = "Fresh root weight (g)")

# Number of nematodes per unit mass (g) of fresh root.
# with(cp, {
#     cbind((count1 + count2) * vol/frw, nemg)
# })

xyplot(nemg ~ ind^0.3 | rootstock,
       data = cp,
       type = c("p", "a"),
       grid = TRUE,
       scales = list(y = "free"),
       xlab = "Initial nematode density (transformed)",
       ylab = "Number of nematodes per fresh root unit mass")

#-----------------------------------------------------------------------
# Cell combinations.

xtabs(~ind + rootstock, data = cp)

## -----------------------------------------------------------------
#-----------------------------------------------------------------------
# Creating auxiliary variables.

log2(unique(cp$ind))

# Replace 0 by 2^{-5} just to plot.
i <- cp$ind == 0

# Indicates if is control (0) or not (1).
cp$ctr <- as.integer(!i)

# Replaces 0 by 2^{-5} to do plots.
cp$ind[i] <- 2^(-5)

# Log base 2 of ind.
cp$lind <- log2(cp$ind)

# Ind as categorical variable.
cp$cind <- factor(cp$lind)

## ---- include = FALSE, eval = FALSE-------------------------------
#  #-----------------------------------------------------------------------
#  
#  xyplot(atw ~ ind | rootstock,
#         data = cp,
#         type = c("p", "a"),
#         grid = TRUE,
#         scales = list(x = list(log = 2)),
#         xlab = "Initial nematode density (log 2 transformed)",
#         ylab = "Aerial top weight (g)")
#  
#  m0 <- lm(atw ~ rootstock * ctr * poly(lind, degree = 1), data = cp)
#  anova(m0)
#  
#  par(mfrow = c(2, 2))
#  plot(m0)
#  layout(1)
#  
#  MASS::boxcox(m0)
#  abline(v = 0, col = 2)
#  
#  xyplot(atw ~ ind | rootstock,
#         data = cp,
#         type = c("p", "a"),
#         grid = TRUE,
#         scales = list(x = list(log = 2), y = list(log = TRUE)),
#         xlab = "Initial nematode density (log 2 transformed)",
#         ylab = "Aerial top weight (g)")
#  
#  m1 <- update(m0, log(.) ~ .)
#  
#  par(mfrow = c(2, 2))
#  plot(m1)
#  layout(1)
#  
#  anova(m1)
#  
#  #-----------------------------------------------------------------------
#  
#  pred <- unique(subset(cp, select = c(rootstock, ctr, lind)))
#  
#  ci <- predict(m1, newdata = pred, interval = "confidence")
#  
#  pred <- cbind(pred, ci)
#  
#  segplot(lind ~ lwr + upr,
#          centers = fit,
#          data = pred,
#          draw = FALSE,
#          horizontal = FALSE,
#          groups = rootstock,
#          gap = 0.1,
#          pch = as.integer(pred$rootstock),
#          panel = panel.groups.segplot)

## -----------------------------------------------------------------
#-----------------------------------------------------------------------
# Using ind as a categorical variable.

m0 <- lm(atw ~ rootstock * cind, data = cp)

# Check model assumptions.
par(mfrow = c(2, 2))
plot(m0)
layout(1)

# How transform?
MASS::boxcox(m0)
abline(v = 0, col = 2)

# Refit with transformed response.
m1 <- update(m0, log(.) ~ .)

# Check model assumptions again.
par(mfrow = c(2, 2))
plot(m1)
layout(1)

# Anova table.
anova(m1)

#-----------------------------------------------------------------------
# Hypothesis tests.

lsm <- LSmeans(m1, effect = c("rootstock", "cind"))
lsm

# Get the matrix that computes least squares means.
L <- lsm$K
grid <- lsm$grid

# Split matrix by rootstock levels and update rownames.
L <- by(data = L, INDICES = grid$rootstock, FUN = as.matrix)
L <- lapply(L, FUN = "rownames<-", unique(grid$cind))

# Return the compact letter display for all contrasts.
pmc <- lapply(L, FUN = apmc, model = m1, test = "fdr", focus = "cind")
pmc

#-----------------------------------------------------------------------

# Stack the list to create a data.frame.
pmc <- ldply(pmc, .id = "rootstock")
str(pmc)

# Reorder levels of factors in pmc according to those in cp.
pmc <- equallevels(x = pmc, y = cp)

pmc <- within(pmc, {
    txt <- sprintf("%0.2f %s", fit, cld)
    xpos <- as.integer(cind) +
        0.6 * scale(as.integer(rootstock), scale = FALSE)
})

pmc$cind <- factor(pmc$cind,
                   labels = c(unique(coffee_pathogenicity$ind)))

key <- list(text = list(levels(pmc$rootstock)),
            points = list(pch = c(1, 19)))

segplot(cind ~ lwr + upr,
        centers = fit,
        data = pmc,
        xlab = "Initial nematode density",
        ylab = "(log) Aerial top weight",
        key = key,
        draw = FALSE,
        horizontal = FALSE,
        groups = rootstock,
        gap = 0.1,
        pch = key$points$pch[as.integer(pmc$rootstock)],
        panel = panel.groups.segplot) +
    layer(panel.text(x = pmc$xpos,
                     y = centers,
                     labels = pmc$txt,
                     srt = 90))

## -----------------------------------------------------------------
#-----------------------------------------------------------------------
# Using ind as a categorical variable.

m0 <- lm(frw ~ rootstock * cind, data = cp)

# Check model assumptions.
par(mfrow = c(2, 2))
plot(m0)
layout(1)

# How transform?
MASS::boxcox(m0)
abline(v = 0, col = 2)

# Refit with transformed response.
m1 <- update(m0, log(.) ~ .)

# Check model assumptions again.
par(mfrow = c(2, 2))
plot(m1)
layout(1)

# Anova table.
anova(m1)

#-----------------------------------------------------------------------
# Hypothesis tests.

lsm <- LSmeans(m1, effect = c("rootstock", "cind"))
lsm

# Get the matrix that computes least squares means.
L <- lsm$K
grid <- lsm$grid

# Split matrix by rootstock levels and update rownames.
L <- by(data = L, INDICES = grid$rootstock, FUN = as.matrix)
L <- lapply(L, FUN = "rownames<-", unique(grid$cind))

# Return the compact letter display for all contrasts.
pmc <- lapply(L, FUN = apmc, model = m1, test = "fdr", focus = "cind")
pmc

#-----------------------------------------------------------------------

# Stack the list to create a data.frame.
pmc <- ldply(pmc, .id = "rootstock")
str(pmc)

# Reorder levels of factors in pmc according to those in cp.
pmc <- equallevels(x = pmc, y = cp)

pmc <- within(pmc, {
    txt <- sprintf("%0.2f %s", fit, cld)
    xpos <- as.integer(cind) +
        0.6 * scale(as.integer(rootstock), scale = FALSE)
})

pmc$cind <- factor(pmc$cind,
                   labels = c(unique(coffee_pathogenicity$ind)))

key <- list(text = list(levels(pmc$rootstock)),
            points = list(pch = c(1, 19)))

segplot(cind ~ lwr + upr,
        centers = fit,
        data = pmc,
        xlab = "Initial nematode density",
        ylab = "(log) Fresh root weight",
        key = key,
        draw = FALSE,
        horizontal = FALSE,
        groups = rootstock,
        gap = 0.1,
        pch = key$points$pch[as.integer(pmc$rootstock)],
        panel = panel.groups.segplot) +
    layer(panel.text(x = pmc$xpos,
                     y = centers,
                     labels = pmc$txt,
                     srt = 90))

## -----------------------------------------------------------------
#-----------------------------------------------------------------------

# Dropout lines with NA.
cp <- droplevels(na.omit(cp))

m0 <- lm(nemg ~ rootstock * cind, data = cp)

# Check model assumptions.
par(mfrow = c(2, 2))
plot(m0)
layout(1)

# How transform?
MASS::boxcox(m0)
abline(v = 0, col = 2)

# Refit with transformed response.
m1 <- update(m0, log(.) ~ .)

# Check model assumptions again.
par(mfrow = c(2, 2))
plot(m1)
layout(1)

# Anova table.
anova(m1)

#-----------------------------------------------------------------------
# Hypothesis tests.

lsm <- LSmeans(m1, effect = c("rootstock", "cind"))
lsm

# Get the matrix that computes least squares means.
L <- lsm$K
grid <- lsm$grid

# Split matrix by rootstock levels and update rownames.
L <- by(data = L, INDICES = grid$rootstock, FUN = as.matrix)
L <- lapply(L, FUN = "rownames<-", unique(grid$cind))

# Return the compact letter display for all contrasts.
pmc <- lapply(L, FUN = apmc, model = m1, test = "fdr", focus = "cind")
pmc

#-----------------------------------------------------------------------

# Stack the list to create a data.frame.
pmc <- ldply(pmc, .id = "rootstock")
str(pmc)

# Reorder levels of factors in pmc according to those in cp.
pmc <- droplevels(equallevels(x = pmc, y = cp))

pmc <- within(pmc, {
    txt <- sprintf("%0.2f %s", fit, cld)
    xpos <- as.integer(cind) +
        0.6 * scale(as.integer(rootstock), scale = FALSE)
})

pmc$cind <- factor(pmc$cind,
                   labels = c(unique(coffee_pathogenicity$ind)[-1]))

key <- list(text = list(levels(pmc$rootstock)),
            points = list(pch = c(1, 19)))

segplot(cind ~ lwr + upr,
        centers = fit,
        data = pmc,
        xlab = "Initial nematode density",
        ylab = "(log) Nematode by fresh root unit mass",
        key = key,
        draw = FALSE,
        horizontal = FALSE,
        groups = rootstock,
        gap = 0.1,
        pch = key$points$pch[as.integer(pmc$rootstock)],
        panel = panel.groups.segplot) +
    layer(panel.text(x = pmc$xpos,
                     y = centers,
                     labels = pmc$txt,
                     srt = 90))

## -----------------------------------------------------------------
#-----------------------------------------------------------------------

cp$count <- with(cp, count1 + count2)
cp$off <- with(cp, frw/vol)
str(cp)

m0 <- glm(count ~ offset(log(off)) + rootstock * cind,
          data = cp,
          family = quasi(variance = "mu^2", link = "log"))
m1 <- glm(count ~ log(off) + rootstock * cind,
          data = cp,
          family = quasi(variance = "mu^2", link = "log"))

anova(m0, m1, test = "F")

# Check model assumptions.
par(mfrow = c(2, 2))
plot(m1)
layout(1)

summary(m1)

# Testa se o \beta do offset é 1.
L <- rep(0, length(coef(m1)))
L[2] <- 1
summary(glht(m1, linfct = rbind(L), rhs = 1))

# m1 <- m0
# Anova table.
anova(m1, test = "F")

#-----------------------------------------------------------------------
# Hypothesis tests.

# Get the matrix that computes least squares means.
grid <- unique(subset(cp, select = c("rootstock", "cind")))
L <- model.matrix(formula(m1)[-2],
                  data = cbind(off = 1, grid))

# Split matrix by rootstock levels and update rownames.
L <- by(data = L, INDICES = grid$rootstock, FUN = as.matrix)
L <- lapply(L, FUN = "rownames<-", unique(grid$cind))

# Return the compact letter display for all contrasts.
pmc <- lapply(L, FUN = apmc, model = m1, test = "fdr", focus = "cind")
pmc

#-----------------------------------------------------------------------

# Stack the list to create a data.frame.
pmc <- ldply(pmc, .id = "rootstock")
str(pmc)

# Reorder levels of factors in pmc according to those in cp.
pmc <- droplevels(equallevels(x = pmc, y = cp))

pmc <- within(pmc, {
    txt <- sprintf("%0.2f %s", fit, cld)
    xpos <- as.integer(cind) +
        0.6 * scale(as.integer(rootstock), scale = FALSE)
})

key <- list(text = list(levels(pmc$rootstock)),
            points = list(pch = c(1, 19)))

segplot(cind ~ lwr + upr,
        centers = fit,
        data = pmc,
        xlab = "Initial nematode density",
        ylab = "(log) Nematode by fresh root unit mass",
        key = key,
        draw = FALSE,
        horizontal = FALSE,
        groups = rootstock,
        gap = 0.1,
        pch = key$points$pch[as.integer(pmc$rootstock)],
        panel = panel.groups.segplot) +
    layer(panel.text(x = pmc$xpos,
                     y = centers,
                     labels = pmc$txt,
                     srt = 90))

## ---- echo = FALSE, results = "hold"------------------------------
cat(format(Sys.time(),
           format = "Updated in %Y-%m-%d.\n\n"))
sessionInfo()

